@@ -46,7 +46,7 @@ class AuthenticationViewSet(GenericEBSViewSet):
         return Response(self.get_serializer(dict(message='Reset password was sent successfully')).data)
 
     @action(detail=False, methods=['POST'], url_path='restore-confirm',
-            serializer_class=ReturnJWTTokensSerializer,
+            serializer_class=settings.SERIALIZERS.RETURN_SUCCESS_SERIALIZER,
             serializer_create_class=settings.SERIALIZERS.RESET_PASSWORD_CONFIRMATION_SERIALIZER)
     def reset_password_confirm(self, request, *args, **kwargs):
         serializer = self.get_serializer_create(data=request.data)
@@ -57,7 +57,7 @@ class AuthenticationViewSet(GenericEBSViewSet):
         reset_password_token.user.set_password(password)
         reset_password_token.user.save()
 
-        return Response(BaseBackend.get_jwt_response(reset_password_token.user))
+        return Response(self.get_serializer(dict(message='Password was reset successfully')).data)
 
     @swagger_auto_schema(method='GET', request_body=no_body, responses={})
     @action(detail=False, methods=['GET'], url_name='logout')
