@@ -40,7 +40,7 @@ class UserViewSet(
         super(UserViewSet, self).destroy(self, request, *args, **kwargs)
         return Response(dict(success=True, message=f"User was successfully deleted"))
 
-    @action(detail=False, methods=['POST'], serializer_create_class=settings.SERIALIZERS.USER_CONFIRM_SERIALIZER,
+    @action(detail=True, methods=['POST'], serializer_create_class=settings.SERIALIZERS.USER_CONFIRM_SERIALIZER,
             serializer_class=ReturnJWTTokensSerializer, url_path='confirm', url_name='confirm')
     def user_confirm(self, request, *args, **kwargs):
         api_settings.SIGNING_KEY = request.service.secret_token
