@@ -7,10 +7,10 @@ from rest_framework.generics import get_object_or_404
 from drf_auth_service.models import ActivationCode
 
 
-def validate_token_by_type(token, code_type):
+def validate_token_by_type(token, code_type, **additional_params):
     password_reset_token_validation_time = 24
 
-    reset_password_token = get_object_or_404(ActivationCode, key=token, key_type=code_type)
+    reset_password_token = get_object_or_404(ActivationCode, key=token, key_type=code_type, **additional_params)
 
     expiry_date = reset_password_token.created_at + timedelta(hours=password_reset_token_validation_time)
 
